pilas.municion

Package pilas :: Module municion |
[hide private]
[frames] | no frames]

# Module municion

source code

Classes | [hide private]
| Municion Clase base para representar un conjunto de proyectiles que pueden ser disparados mediante la habilidad de Disparar.
| BalaDoble Munición que dispara 2 balas paralelas.
| BalasDoblesDesviadas Munición que dispara 2 balas en angulos distintos.
| MisilDoble Munición que dispara 2 misiles paralelos que aceleran poco a poco.

Variables | [hide private]
| __package__ = ``'``pilas``'``